:root{
  --wp-admin-theme-color:#007cba;
  --wp-admin-theme-color--rgb:0, 124, 186;
  --wp-admin-theme-color-darker-10:#006ba1;
  --wp-admin-theme-color-darker-10--rgb:0, 107, 161;
  --wp-admin-theme-color-darker-20:#005a87;
  --wp-admin-theme-color-darker-20--rgb:0, 90, 135;
  --wp-admin-border-width-focus:2px;
  --wp-block-synced-color:#7a00df;
  --wp-block-synced-color--rgb:122, 0, 223;
  --wp-bound-block-color:var(--wp-block-synced-color);
}
@media (min-resolution:192dpi){
  :root{
    --wp-admin-border-width-focus:1.5px;
  }
}

.preference-base-option+.preference-base-option{
  margin-top:16px;
}
.preference-base-option .components-base-control__help{
  margin-right:48px;
  margin-top:0;
}

@media (min-width:600px){
  .preferences-modal{
    height:calc(100% - 120px);
    width:calc(100% - 32px);
  }
}
@media (min-width:782px){
  .preferences-modal{
    width:750px;
  }
}
@media (min-width:960px){
  .preferences-modal{
    height:70%;
  }
}
@media (max-width:781px){
  .preferences-modal .components-modal__content{
    padding:0;
  }
}

.preferences__tabs-tablist{
  position:absolute !important;
  right:16px;
  top:84px;
  width:160px;
}
.preferences__tabs-tablist:after{
  content:none !important;
}

.preferences__tabs-tab{
  border-radius:2px;
  font-weight:400;
}
.preferences__tabs-tab[aria-selected=true]{
  background:#f0f0f0;
  box-shadow:none;
  font-weight:500;
}
.preferences__tabs-tab[role=tab]:focus:not(:disabled){
  box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
  outline:2px solid #0000;
}
.preferences__tabs-tab:focus-visible:before{
  content:none;
}

.preferences__tabs-tabpanel{
  margin-right:160px;
  padding-right:24px;
}

@media (max-width:781px){
  .preferences__provider{
    height:100%;
  }
}
.preferences-modal__section{
  margin:0 0 2.5rem;
}
.preferences-modal__section:last-child{
  margin:0;
}

.preferences-modal__section-legend{
  margin-bottom:8px;
}

.preferences-modal__section-title{
  font-size:.9rem;
  font-weight:600;
  margin-top:0;
}

.preferences-modal__section-description{
  color:#757575;
  font-size:12px;
  font-style:normal;
  margin:-8px 0 8px;
}

.preferences-modal__section:has(.preferences-modal__section-content:empty){
  display:none;
}